%global pypi_name modbus-proxy
%global pypi_version 0.8.0

Name:           %{pypi_name}
Version:        %{pypi_version}
Release:        2%{?dist}
Summary:        ModBus TCP proxy

License:        GPLv3+
URL:            https://github.com/tiagocoutinho/modbus-proxy
Source0:        %{pypi_source}
# Sample configuration file
Source1:        modbus-proxy-0.6.8-modbus-proxy.yaml
# Reported upstream: https://github.com/tiagocoutinho/modbus-proxy/pull/40
Source2:        modbus-proxy-0.6.8-systemd-service

# Reported upstream: https://github.com/tiagocoutinho/modbus-proxy/pull/38
Patch:          modbus-proxy-0.8.0-0001-Fix-incorrect-PYTHONPATH-during-tests.patch
# Reported upstream: https://github.com/tiagocoutinho/modbus-proxy/pull/39
Patch:          modbus-proxy-0.8.0-Relax-minimum-required-version-of-dependencies.patch
# Disable installing unneeded dependency not available in Fedora.
Patch:          modbus-proxy-0.8.0-Disable-installing-bumpversion.patch

BuildArch:      noarch

BuildRequires:  systemd-rpm-macros


%description
Many modbus devices support only one or very few clients.
This proxy acts as a bridge between the client and the modbus device.
It can be seen as a layer 7 reverse proxy. This allows multiple
clients to communicate with the same modbus device.


%prep
%autosetup -n %{pypi_name}-%{pypi_version}

%generate_buildrequires
%pyproject_buildrequires -t


%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files modbus_proxy

# Install sample configuration file
install -p -m 0644 -D %{SOURCE1} %{buildroot}%{_sysconfdir}/%{name}.yaml

# Install systemd service file
install -p -m 0644 -D %{SOURCE2} %{buildroot}%{_unitdir}/%{name}.service


%check
%tox


%files -f %{pyproject_files}
%doc README.md
%{_bindir}/modbus-proxy
%config(noreplace) %{_sysconfdir}/%{name}.yaml
%{_unitdir}/%{name}.service


%post
%systemd_post %{name}.service

%preun
%systemd_preun %{name}.service

%postun
%systemd_postun_with_restart %{name}.service


%changelog
* Tue Sep 03 2024 Damian Wrobel <dwrobel@ertelnet.rybnik.pl> - 0.8.0-2
- Update to the latest available version

* Wed Feb 28 2024 Damian Wrobel <dwrobel@ertelnet.rybnik.pl> - 0.6.8-5
- Rebuild for new Fedora

* Wed Jan 17 2024 Damian Wrobel <dwrobel@ertelnet.rybnik.pl> - 0.6.8-4
- Rebuild for F39

* Wed Jul 12 2023 Damian Wrobel <dwrobel@ertelnet.rybnik.pl> - 0.6.8-3
- Rebuild for python-3.12

* Wed Nov 23 2022 Damian Wrobel <dwrobel@ertelnet.rybnik.pl> - 0.6.8-2
- Add systemd service and sample configuration files.

* Mon Nov 21 2022 Damian Wrobel <dwrobel@ertelnet.rybnik.pl> - 0.6.8-1
- Initial package.
